#[doc = "Register `F10DATA0` reader"]
pub struct R(crate::R<F10DATA0_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<F10DATA0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<F10DATA0_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<F10DATA0_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `F10DATA0` writer"]
pub struct W(crate::W<F10DATA0_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<F10DATA0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<F10DATA0_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<F10DATA0_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `FD0` reader - Filter data"]
pub struct FD0_R(crate::FieldReader<bool, bool>);
impl FD0_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD0_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD0_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD0` writer - Filter data"]
pub struct FD0_W<'a> {
    w: &'a mut W,
}
impl<'a> FD0_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
        self.w
    }
}
#[doc = "Field `FD1` reader - Filter data"]
pub struct FD1_R(crate::FieldReader<bool, bool>);
impl FD1_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD1_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD1_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD1` writer - Filter data"]
pub struct FD1_W<'a> {
    w: &'a mut W,
}
impl<'a> FD1_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
        self.w
    }
}
#[doc = "Field `FD2` reader - Filter data"]
pub struct FD2_R(crate::FieldReader<bool, bool>);
impl FD2_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD2_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD2_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD2` writer - Filter data"]
pub struct FD2_W<'a> {
    w: &'a mut W,
}
impl<'a> FD2_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
        self.w
    }
}
#[doc = "Field `FD3` reader - Filter data"]
pub struct FD3_R(crate::FieldReader<bool, bool>);
impl FD3_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD3_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD3_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD3` writer - Filter data"]
pub struct FD3_W<'a> {
    w: &'a mut W,
}
impl<'a> FD3_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
        self.w
    }
}
#[doc = "Field `FD4` reader - Filter data"]
pub struct FD4_R(crate::FieldReader<bool, bool>);
impl FD4_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD4_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD4_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD4` writer - Filter data"]
pub struct FD4_W<'a> {
    w: &'a mut W,
}
impl<'a> FD4_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
        self.w
    }
}
#[doc = "Field `FD5` reader - Filter data"]
pub struct FD5_R(crate::FieldReader<bool, bool>);
impl FD5_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD5_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD5_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD5` writer - Filter data"]
pub struct FD5_W<'a> {
    w: &'a mut W,
}
impl<'a> FD5_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
        self.w
    }
}
#[doc = "Field `FD6` reader - Filter data"]
pub struct FD6_R(crate::FieldReader<bool, bool>);
impl FD6_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD6_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD6_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD6` writer - Filter data"]
pub struct FD6_W<'a> {
    w: &'a mut W,
}
impl<'a> FD6_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
        self.w
    }
}
#[doc = "Field `FD7` reader - Filter data"]
pub struct FD7_R(crate::FieldReader<bool, bool>);
impl FD7_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD7_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD7_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD7` writer - Filter data"]
pub struct FD7_W<'a> {
    w: &'a mut W,
}
impl<'a> FD7_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
        self.w
    }
}
#[doc = "Field `FD8` reader - Filter data"]
pub struct FD8_R(crate::FieldReader<bool, bool>);
impl FD8_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD8_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD8_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD8` writer - Filter data"]
pub struct FD8_W<'a> {
    w: &'a mut W,
}
impl<'a> FD8_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
        self.w
    }
}
#[doc = "Field `FD9` reader - Filter data"]
pub struct FD9_R(crate::FieldReader<bool, bool>);
impl FD9_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD9_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD9_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD9` writer - Filter data"]
pub struct FD9_W<'a> {
    w: &'a mut W,
}
impl<'a> FD9_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
        self.w
    }
}
#[doc = "Field `FD10` reader - Filter data"]
pub struct FD10_R(crate::FieldReader<bool, bool>);
impl FD10_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD10_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD10_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD10` writer - Filter data"]
pub struct FD10_W<'a> {
    w: &'a mut W,
}
impl<'a> FD10_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
        self.w
    }
}
#[doc = "Field `FD11` reader - Filter data"]
pub struct FD11_R(crate::FieldReader<bool, bool>);
impl FD11_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD11_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD11_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD11` writer - Filter data"]
pub struct FD11_W<'a> {
    w: &'a mut W,
}
impl<'a> FD11_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
        self.w
    }
}
#[doc = "Field `FD12` reader - Filter data"]
pub struct FD12_R(crate::FieldReader<bool, bool>);
impl FD12_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD12_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD12_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD12` writer - Filter data"]
pub struct FD12_W<'a> {
    w: &'a mut W,
}
impl<'a> FD12_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
        self.w
    }
}
#[doc = "Field `FD13` reader - Filter data"]
pub struct FD13_R(crate::FieldReader<bool, bool>);
impl FD13_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD13_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD13_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD13` writer - Filter data"]
pub struct FD13_W<'a> {
    w: &'a mut W,
}
impl<'a> FD13_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
        self.w
    }
}
#[doc = "Field `FD14` reader - Filter data"]
pub struct FD14_R(crate::FieldReader<bool, bool>);
impl FD14_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD14_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD14_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD14` writer - Filter data"]
pub struct FD14_W<'a> {
    w: &'a mut W,
}
impl<'a> FD14_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
        self.w
    }
}
#[doc = "Field `FD15` reader - Filter data"]
pub struct FD15_R(crate::FieldReader<bool, bool>);
impl FD15_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD15_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD15_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD15` writer - Filter data"]
pub struct FD15_W<'a> {
    w: &'a mut W,
}
impl<'a> FD15_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
        self.w
    }
}
#[doc = "Field `FD16` reader - Filter data"]
pub struct FD16_R(crate::FieldReader<bool, bool>);
impl FD16_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD16_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD16_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD16` writer - Filter data"]
pub struct FD16_W<'a> {
    w: &'a mut W,
}
impl<'a> FD16_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
        self.w
    }
}
#[doc = "Field `FD17` reader - Filter data"]
pub struct FD17_R(crate::FieldReader<bool, bool>);
impl FD17_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD17_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD17_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD17` writer - Filter data"]
pub struct FD17_W<'a> {
    w: &'a mut W,
}
impl<'a> FD17_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
        self.w
    }
}
#[doc = "Field `FD18` reader - Filter data"]
pub struct FD18_R(crate::FieldReader<bool, bool>);
impl FD18_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD18_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD18_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD18` writer - Filter data"]
pub struct FD18_W<'a> {
    w: &'a mut W,
}
impl<'a> FD18_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
        self.w
    }
}
#[doc = "Field `FD19` reader - Filter data"]
pub struct FD19_R(crate::FieldReader<bool, bool>);
impl FD19_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD19_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD19_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD19` writer - Filter data"]
pub struct FD19_W<'a> {
    w: &'a mut W,
}
impl<'a> FD19_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
        self.w
    }
}
#[doc = "Field `FD20` reader - Filter data"]
pub struct FD20_R(crate::FieldReader<bool, bool>);
impl FD20_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD20_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD20_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD20` writer - Filter data"]
pub struct FD20_W<'a> {
    w: &'a mut W,
}
impl<'a> FD20_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
        self.w
    }
}
#[doc = "Field `FD21` reader - Filter data"]
pub struct FD21_R(crate::FieldReader<bool, bool>);
impl FD21_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD21_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD21_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD21` writer - Filter data"]
pub struct FD21_W<'a> {
    w: &'a mut W,
}
impl<'a> FD21_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
        self.w
    }
}
#[doc = "Field `FD22` reader - Filter data"]
pub struct FD22_R(crate::FieldReader<bool, bool>);
impl FD22_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD22_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD22_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD22` writer - Filter data"]
pub struct FD22_W<'a> {
    w: &'a mut W,
}
impl<'a> FD22_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
        self.w
    }
}
#[doc = "Field `FD23` reader - Filter data"]
pub struct FD23_R(crate::FieldReader<bool, bool>);
impl FD23_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD23_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD23_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD23` writer - Filter data"]
pub struct FD23_W<'a> {
    w: &'a mut W,
}
impl<'a> FD23_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
        self.w
    }
}
#[doc = "Field `FD24` reader - Filter data"]
pub struct FD24_R(crate::FieldReader<bool, bool>);
impl FD24_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD24_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD24_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD24` writer - Filter data"]
pub struct FD24_W<'a> {
    w: &'a mut W,
}
impl<'a> FD24_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
        self.w
    }
}
#[doc = "Field `FD25` reader - Filter data"]
pub struct FD25_R(crate::FieldReader<bool, bool>);
impl FD25_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD25_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD25_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD25` writer - Filter data"]
pub struct FD25_W<'a> {
    w: &'a mut W,
}
impl<'a> FD25_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
        self.w
    }
}
#[doc = "Field `FD26` reader - Filter data"]
pub struct FD26_R(crate::FieldReader<bool, bool>);
impl FD26_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD26_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD26_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD26` writer - Filter data"]
pub struct FD26_W<'a> {
    w: &'a mut W,
}
impl<'a> FD26_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
        self.w
    }
}
#[doc = "Field `FD27` reader - Filter data"]
pub struct FD27_R(crate::FieldReader<bool, bool>);
impl FD27_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD27_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD27_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD27` writer - Filter data"]
pub struct FD27_W<'a> {
    w: &'a mut W,
}
impl<'a> FD27_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
        self.w
    }
}
#[doc = "Field `FD28` reader - Filter data"]
pub struct FD28_R(crate::FieldReader<bool, bool>);
impl FD28_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD28_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD28_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD28` writer - Filter data"]
pub struct FD28_W<'a> {
    w: &'a mut W,
}
impl<'a> FD28_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
        self.w
    }
}
#[doc = "Field `FD29` reader - Filter data"]
pub struct FD29_R(crate::FieldReader<bool, bool>);
impl FD29_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD29_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD29_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD29` writer - Filter data"]
pub struct FD29_W<'a> {
    w: &'a mut W,
}
impl<'a> FD29_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
        self.w
    }
}
#[doc = "Field `FD30` reader - Filter data"]
pub struct FD30_R(crate::FieldReader<bool, bool>);
impl FD30_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD30_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD30_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD30` writer - Filter data"]
pub struct FD30_W<'a> {
    w: &'a mut W,
}
impl<'a> FD30_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
        self.w
    }
}
#[doc = "Field `FD31` reader - Filter data"]
pub struct FD31_R(crate::FieldReader<bool, bool>);
impl FD31_R {
    pub(crate) fn new(bits: bool) -> Self {
        FD31_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FD31_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `FD31` writer - Filter data"]
pub struct FD31_W<'a> {
    w: &'a mut W,
}
impl<'a> FD31_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
        self.w
    }
}
impl R {
    #[doc = "Bit 0 - Filter data"]
    #[inline(always)]
    pub fn fd0(&self) -> FD0_R {
        FD0_R::new((self.bits & 0x01) != 0)
    }
    #[doc = "Bit 1 - Filter data"]
    #[inline(always)]
    pub fn fd1(&self) -> FD1_R {
        FD1_R::new(((self.bits >> 1) & 0x01) != 0)
    }
    #[doc = "Bit 2 - Filter data"]
    #[inline(always)]
    pub fn fd2(&self) -> FD2_R {
        FD2_R::new(((self.bits >> 2) & 0x01) != 0)
    }
    #[doc = "Bit 3 - Filter data"]
    #[inline(always)]
    pub fn fd3(&self) -> FD3_R {
        FD3_R::new(((self.bits >> 3) & 0x01) != 0)
    }
    #[doc = "Bit 4 - Filter data"]
    #[inline(always)]
    pub fn fd4(&self) -> FD4_R {
        FD4_R::new(((self.bits >> 4) & 0x01) != 0)
    }
    #[doc = "Bit 5 - Filter data"]
    #[inline(always)]
    pub fn fd5(&self) -> FD5_R {
        FD5_R::new(((self.bits >> 5) & 0x01) != 0)
    }
    #[doc = "Bit 6 - Filter data"]
    #[inline(always)]
    pub fn fd6(&self) -> FD6_R {
        FD6_R::new(((self.bits >> 6) & 0x01) != 0)
    }
    #[doc = "Bit 7 - Filter data"]
    #[inline(always)]
    pub fn fd7(&self) -> FD7_R {
        FD7_R::new(((self.bits >> 7) & 0x01) != 0)
    }
    #[doc = "Bit 8 - Filter data"]
    #[inline(always)]
    pub fn fd8(&self) -> FD8_R {
        FD8_R::new(((self.bits >> 8) & 0x01) != 0)
    }
    #[doc = "Bit 9 - Filter data"]
    #[inline(always)]
    pub fn fd9(&self) -> FD9_R {
        FD9_R::new(((self.bits >> 9) & 0x01) != 0)
    }
    #[doc = "Bit 10 - Filter data"]
    #[inline(always)]
    pub fn fd10(&self) -> FD10_R {
        FD10_R::new(((self.bits >> 10) & 0x01) != 0)
    }
    #[doc = "Bit 11 - Filter data"]
    #[inline(always)]
    pub fn fd11(&self) -> FD11_R {
        FD11_R::new(((self.bits >> 11) & 0x01) != 0)
    }
    #[doc = "Bit 12 - Filter data"]
    #[inline(always)]
    pub fn fd12(&self) -> FD12_R {
        FD12_R::new(((self.bits >> 12) & 0x01) != 0)
    }
    #[doc = "Bit 13 - Filter data"]
    #[inline(always)]
    pub fn fd13(&self) -> FD13_R {
        FD13_R::new(((self.bits >> 13) & 0x01) != 0)
    }
    #[doc = "Bit 14 - Filter data"]
    #[inline(always)]
    pub fn fd14(&self) -> FD14_R {
        FD14_R::new(((self.bits >> 14) & 0x01) != 0)
    }
    #[doc = "Bit 15 - Filter data"]
    #[inline(always)]
    pub fn fd15(&self) -> FD15_R {
        FD15_R::new(((self.bits >> 15) & 0x01) != 0)
    }
    #[doc = "Bit 16 - Filter data"]
    #[inline(always)]
    pub fn fd16(&self) -> FD16_R {
        FD16_R::new(((self.bits >> 16) & 0x01) != 0)
    }
    #[doc = "Bit 17 - Filter data"]
    #[inline(always)]
    pub fn fd17(&self) -> FD17_R {
        FD17_R::new(((self.bits >> 17) & 0x01) != 0)
    }
    #[doc = "Bit 18 - Filter data"]
    #[inline(always)]
    pub fn fd18(&self) -> FD18_R {
        FD18_R::new(((self.bits >> 18) & 0x01) != 0)
    }
    #[doc = "Bit 19 - Filter data"]
    #[inline(always)]
    pub fn fd19(&self) -> FD19_R {
        FD19_R::new(((self.bits >> 19) & 0x01) != 0)
    }
    #[doc = "Bit 20 - Filter data"]
    #[inline(always)]
    pub fn fd20(&self) -> FD20_R {
        FD20_R::new(((self.bits >> 20) & 0x01) != 0)
    }
    #[doc = "Bit 21 - Filter data"]
    #[inline(always)]
    pub fn fd21(&self) -> FD21_R {
        FD21_R::new(((self.bits >> 21) & 0x01) != 0)
    }
    #[doc = "Bit 22 - Filter data"]
    #[inline(always)]
    pub fn fd22(&self) -> FD22_R {
        FD22_R::new(((self.bits >> 22) & 0x01) != 0)
    }
    #[doc = "Bit 23 - Filter data"]
    #[inline(always)]
    pub fn fd23(&self) -> FD23_R {
        FD23_R::new(((self.bits >> 23) & 0x01) != 0)
    }
    #[doc = "Bit 24 - Filter data"]
    #[inline(always)]
    pub fn fd24(&self) -> FD24_R {
        FD24_R::new(((self.bits >> 24) & 0x01) != 0)
    }
    #[doc = "Bit 25 - Filter data"]
    #[inline(always)]
    pub fn fd25(&self) -> FD25_R {
        FD25_R::new(((self.bits >> 25) & 0x01) != 0)
    }
    #[doc = "Bit 26 - Filter data"]
    #[inline(always)]
    pub fn fd26(&self) -> FD26_R {
        FD26_R::new(((self.bits >> 26) & 0x01) != 0)
    }
    #[doc = "Bit 27 - Filter data"]
    #[inline(always)]
    pub fn fd27(&self) -> FD27_R {
        FD27_R::new(((self.bits >> 27) & 0x01) != 0)
    }
    #[doc = "Bit 28 - Filter data"]
    #[inline(always)]
    pub fn fd28(&self) -> FD28_R {
        FD28_R::new(((self.bits >> 28) & 0x01) != 0)
    }
    #[doc = "Bit 29 - Filter data"]
    #[inline(always)]
    pub fn fd29(&self) -> FD29_R {
        FD29_R::new(((self.bits >> 29) & 0x01) != 0)
    }
    #[doc = "Bit 30 - Filter data"]
    #[inline(always)]
    pub fn fd30(&self) -> FD30_R {
        FD30_R::new(((self.bits >> 30) & 0x01) != 0)
    }
    #[doc = "Bit 31 - Filter data"]
    #[inline(always)]
    pub fn fd31(&self) -> FD31_R {
        FD31_R::new(((self.bits >> 31) & 0x01) != 0)
    }
}
impl W {
    #[doc = "Bit 0 - Filter data"]
    #[inline(always)]
    pub fn fd0(&mut self) -> FD0_W {
        FD0_W { w: self }
    }
    #[doc = "Bit 1 - Filter data"]
    #[inline(always)]
    pub fn fd1(&mut self) -> FD1_W {
        FD1_W { w: self }
    }
    #[doc = "Bit 2 - Filter data"]
    #[inline(always)]
    pub fn fd2(&mut self) -> FD2_W {
        FD2_W { w: self }
    }
    #[doc = "Bit 3 - Filter data"]
    #[inline(always)]
    pub fn fd3(&mut self) -> FD3_W {
        FD3_W { w: self }
    }
    #[doc = "Bit 4 - Filter data"]
    #[inline(always)]
    pub fn fd4(&mut self) -> FD4_W {
        FD4_W { w: self }
    }
    #[doc = "Bit 5 - Filter data"]
    #[inline(always)]
    pub fn fd5(&mut self) -> FD5_W {
        FD5_W { w: self }
    }
    #[doc = "Bit 6 - Filter data"]
    #[inline(always)]
    pub fn fd6(&mut self) -> FD6_W {
        FD6_W { w: self }
    }
    #[doc = "Bit 7 - Filter data"]
    #[inline(always)]
    pub fn fd7(&mut self) -> FD7_W {
        FD7_W { w: self }
    }
    #[doc = "Bit 8 - Filter data"]
    #[inline(always)]
    pub fn fd8(&mut self) -> FD8_W {
        FD8_W { w: self }
    }
    #[doc = "Bit 9 - Filter data"]
    #[inline(always)]
    pub fn fd9(&mut self) -> FD9_W {
        FD9_W { w: self }
    }
    #[doc = "Bit 10 - Filter data"]
    #[inline(always)]
    pub fn fd10(&mut self) -> FD10_W {
        FD10_W { w: self }
    }
    #[doc = "Bit 11 - Filter data"]
    #[inline(always)]
    pub fn fd11(&mut self) -> FD11_W {
        FD11_W { w: self }
    }
    #[doc = "Bit 12 - Filter data"]
    #[inline(always)]
    pub fn fd12(&mut self) -> FD12_W {
        FD12_W { w: self }
    }
    #[doc = "Bit 13 - Filter data"]
    #[inline(always)]
    pub fn fd13(&mut self) -> FD13_W {
        FD13_W { w: self }
    }
    #[doc = "Bit 14 - Filter data"]
    #[inline(always)]
    pub fn fd14(&mut self) -> FD14_W {
        FD14_W { w: self }
    }
    #[doc = "Bit 15 - Filter data"]
    #[inline(always)]
    pub fn fd15(&mut self) -> FD15_W {
        FD15_W { w: self }
    }
    #[doc = "Bit 16 - Filter data"]
    #[inline(always)]
    pub fn fd16(&mut self) -> FD16_W {
        FD16_W { w: self }
    }
    #[doc = "Bit 17 - Filter data"]
    #[inline(always)]
    pub fn fd17(&mut self) -> FD17_W {
        FD17_W { w: self }
    }
    #[doc = "Bit 18 - Filter data"]
    #[inline(always)]
    pub fn fd18(&mut self) -> FD18_W {
        FD18_W { w: self }
    }
    #[doc = "Bit 19 - Filter data"]
    #[inline(always)]
    pub fn fd19(&mut self) -> FD19_W {
        FD19_W { w: self }
    }
    #[doc = "Bit 20 - Filter data"]
    #[inline(always)]
    pub fn fd20(&mut self) -> FD20_W {
        FD20_W { w: self }
    }
    #[doc = "Bit 21 - Filter data"]
    #[inline(always)]
    pub fn fd21(&mut self) -> FD21_W {
        FD21_W { w: self }
    }
    #[doc = "Bit 22 - Filter data"]
    #[inline(always)]
    pub fn fd22(&mut self) -> FD22_W {
        FD22_W { w: self }
    }
    #[doc = "Bit 23 - Filter data"]
    #[inline(always)]
    pub fn fd23(&mut self) -> FD23_W {
        FD23_W { w: self }
    }
    #[doc = "Bit 24 - Filter data"]
    #[inline(always)]
    pub fn fd24(&mut self) -> FD24_W {
        FD24_W { w: self }
    }
    #[doc = "Bit 25 - Filter data"]
    #[inline(always)]
    pub fn fd25(&mut self) -> FD25_W {
        FD25_W { w: self }
    }
    #[doc = "Bit 26 - Filter data"]
    #[inline(always)]
    pub fn fd26(&mut self) -> FD26_W {
        FD26_W { w: self }
    }
    #[doc = "Bit 27 - Filter data"]
    #[inline(always)]
    pub fn fd27(&mut self) -> FD27_W {
        FD27_W { w: self }
    }
    #[doc = "Bit 28 - Filter data"]
    #[inline(always)]
    pub fn fd28(&mut self) -> FD28_W {
        FD28_W { w: self }
    }
    #[doc = "Bit 29 - Filter data"]
    #[inline(always)]
    pub fn fd29(&mut self) -> FD29_W {
        FD29_W { w: self }
    }
    #[doc = "Bit 30 - Filter data"]
    #[inline(always)]
    pub fn fd30(&mut self) -> FD30_W {
        FD30_W { w: self }
    }
    #[doc = "Bit 31 - Filter data"]
    #[inline(always)]
    pub fn fd31(&mut self) -> FD31_W {
        FD31_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Filter 10 data 0 register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [f10data0](index.html) module"]
pub struct F10DATA0_SPEC;
impl crate::RegisterSpec for F10DATA0_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [f10data0::R](R) reader structure"]
impl crate::Readable for F10DATA0_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [f10data0::W](W) writer structure"]
impl crate::Writable for F10DATA0_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets F10DATA0 to value 0"]
impl crate::Resettable for F10DATA0_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
